import { select, json, tree, hierarchy, linkHorizontal, zoom, event } from 'd3';

const svg = select('svg');

const width = document.body.clientWidth;
const height = document.body.clientHeight;
//margin convention
const marginConv = { top:0, right:15, bottom: 0, left: 70}
const innerWidth = width - marginConv.left - marginConv.right;
const innerHeight = height - marginConv.top - marginConv.bottom;


const zoomG = svg
  	.attr('width', width)
	//.attr('height', height);
		.attr('height', height)
	.append('g');
		

const g = zoomG.append('g')
	.attr('transform', `translate(${marginConv.left}, ${marginConv.top})`);

svg.call(zoom().on('zoom', () => {
  	g.attr('transform', event.transform);
	}));


		

//see : github.com/d3/d3-hierarchy
//see : github.com/d3/d3-shape for linkHorizontal
const tidyTree = tree().size([innerHeight, innerWidth]); 



//returns a promise, loading data
json('data.json')
	.then(data => {
  	const root = hierarchy(data);
  	//invoke tree, .links() returns an array of objects
  	const links = tidyTree(root).links();
  	const linkPathGenerator = linkHorizontal()
    	//for vertical tree : import linkVertical
      .x(d => d.y)
      .y(d => d.x);
  	
  	//constructing paths for links 
  	g.selectAll('path').data(links)
  		.enter().append('path')
  			.attr('d', linkPathGenerator);
  
  	//adding labels to nodes
  	//root.descendants() : gives all the nodes of the tree
  	g.selectAll('text').data(root.descendants())
  		.enter().append('text')
  			.attr('x', d => d.y)
  			.attr('y', d => d.x)
  			.attr('dy', '0.32em')
  			.attr('text-anchor', d => d.children ? 'middle' : 'start')
  			.attr('font-size', d => 3.2 - d.depth + 'em')
  			.text(d => d.data.data.id);
  	
  
	});
